five_digits_zero_padded

Function five_digits_zero_padded 

pub(crate) const fn five_digits_zero_padded(
    n: ru32<0, 99_999>,
) -> [&'static str; 3]
Available on crate feature formatting only.
Obtain three strings which together represent n. The first string is the most significant. Leading zeros are included if the number has fewer than 5 digits. The first string will be empty if n is less than 10,000.