four_to_six_digits

Function four_to_six_digits 

pub(crate) const fn four_to_six_digits(n: ru32<0, 999_999>) -> [&'static str; 3]
Obtain three strings which together represent n. The first string is the most significant. Leading zeros are included if the number has fewer than 4 digits. The first string will be empty if n is less than 10,000.