subsecond_from_nanos

Function subsecond_from_nanos 

pub(crate) const fn subsecond_from_nanos(
    n: ru32<0, 999_999_999>,
) -> [&'static str; 5]
Obtain five strings which together represent n, which is a number of nanoseconds.

This value is intended to be used after a decimal point to represent a fractional second. The first string will always contain exactly one digit; the remaining four will contain two digits each.